@@ -4,13 +4,15 @@ describe 'aodh::api' do
 
   let :pre_condition do
     "class { 'aodh': }
-     include ::aodh::db"
+     include ::aodh::db
+     class { '::aodh::keystone::authtoken':
+       password => 'a_big_secret',
+     }"
   end
 
   let :params do
     { :enabled           => true,
       :manage_service    => true,
-      :keystone_password => 'aodh-passw0rd',
       :package_ensure    => 'latest',
       :port              => '8042',
       :host              => '0.0.0.0',
@@ -19,6 +21,7 @@ describe 'aodh::api' do
 
   shared_examples_for 'aodh-api' do
 
+    it { is_expected.to contain_class('aodh::deps') }
     it { is_expected.to contain_class('aodh::params') }
     it { is_expected.to contain_class('aodh::policy') }
 
@@ -33,6 +36,11 @@ describe 'aodh::api' do
     it 'configures api' do
       is_expected.to contain_aodh_config('api/host').with_value( params[:host] )
       is_expected.to contain_aodh_config('api/port').with_value( params[:port] )
+      is_expected.to contain_aodh_config('api/gnocchi_external_project_owner').with_value( 'services' )
+      is_expected.to contain_aodh_config('api/paste_config').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_oslo__middleware('aodh_config').with(
+        :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
+      )
     end
 
     [{:enabled => true}, {:enabled => false}].each do |param_hash|
@@ -48,10 +56,11 @@ describe 'aodh::api' do
             :enable     => params[:enabled],
             :hasstatus  => true,
             :hasrestart => true,
-            :require    => 'Class[Aodh::Db]',
             :tag        => 'aodh-service',
           )
         end
+        it { is_expected.to contain_service('aodh-api').that_subscribes_to('Anchor[aodh::service::begin]')}
+        it { is_expected.to contain_service('aodh-api').that_notifies('Anchor[aodh::service::end]')}
       end
     end
 
@@ -63,44 +72,31 @@ describe 'aodh::api' do
       it { is_expected.to contain_class('aodh::db::sync') }
     end
 
-
-    context 'with deprecated parameters' do
+    context 'with enable_proxy_headers_parsing' do
       before do
-        params.merge!({
-          :keystone_user                => 'dummy',
-          :keystone_password            => 'mypassword',
-          :keystone_tenant              => 'tenant',
-          :keystone_auth_uri            => 'https://10.0.0.1:5000/deprecated',
-          :keystone_identity_uri        => 'https://10.0.0.1:35357/deprecated',
-          :keystone_auth_url            => 'https://10.0.0.1:35357/deprecated',
-          :memcached_servers            => ['memcached01:11211','memcached02:11211'],
-          :keystone_project_domain_name => 'domainX',
-          :keystone_user_domain_name    => 'domainX',
-          :keystone_auth_type           => 'auth',
-        })
-      end
-      it 'configures keystone_authtoken middleware' do
-        is_expected.to contain_aodh_config(
-          'keystone_authtoken/auth_uri').with_value('https://10.0.0.1:5000/deprecated')
-        is_expected.to contain_aodh_config(
-          'keystone_authtoken/username').with_value(params[:keystone_user])
-        is_expected.to contain_aodh_config(
-          'keystone_authtoken/password').with_value(params[:keystone_password]).with_secret(true)
-        is_expected.to contain_aodh_config(
-          'keystone_authtoken/auth_url').with_value(params[:keystone_identity_uri])
-        is_expected.to contain_aodh_config(
-          'keystone_authtoken/project_name').with_value(params[:keystone_tenant])
-        is_expected.to contain_aodh_config(
-          'keystone_authtoken/user_domain_name').with_value(params[:keystone_user_domain_name])
-        is_expected.to contain_aodh_config(
-          'keystone_authtoken/project_domain_name').with_value(params[:keystone_project_domain_name])
-        is_expected.to contain_aodh_config(
-          'keystone_authtoken/auth_type').with_value(params[:keystone_auth_type])
-        is_expected.to contain_aodh_config(
-          'keystone_authtoken/memcached_servers').with_value('memcached01:11211,memcached02:11211')
+        params.merge!({:enable_proxy_headers_parsing => true })
       end
+
+      it { is_expected.to contain_oslo__middleware('aodh_config').with(
+        :enable_proxy_headers_parsing => true,
+      )}
     end
 
+    context 'with paste_config' do
+      before do
+        params.merge!({:paste_config => '/etc/aodh/api-paste.ini' })
+      end
+
+      it { is_expected.to contain_aodh_config('api/paste_config').with_value('/etc/aodh/api-paste.ini') }
+    end
+
+    context 'with gnocchi_external_project_owner' do
+      before do
+        params.merge!({:gnocchi_external_project_owner => 'gnocchi-project' })
+      end
+
+      it { is_expected.to contain_aodh_config('api/gnocchi_external_project_owner').with_value('gnocchi-project') }
+    end
     context 'with disabled service managing' do
       before do
         params.merge!({
@@ -128,7 +124,10 @@ describe 'aodh::api' do
       let :pre_condition do
         "include ::apache
          include ::aodh::db
-         class { 'aodh': }"
+         class { 'aodh': }
+         class { '::aodh::keystone::authtoken':
+           password => 'a_big_secret',
+         }"
       end
 
       it 'configures aodh-api service with Apache' do
@@ -149,37 +148,14 @@ describe 'aodh::api' do
       let :pre_condition do
         "include ::apache
          include ::aodh::db
-         class { 'aodh': }"
+         class { 'aodh': }
+         class { '::aodh::keystone::authtoken':
+           password => 'a_big_secret',
+         }"
       end
 
       it_raises 'a Puppet::Error', /Invalid service_name/
     end
-
-    context "with deprecated keystone options" do
-      before do
-        params.merge!({
-          :keystone_user                => 'user',
-          :keystone_password            => 'userpassword',
-          :keystone_tenant              => 'tenant',
-          :keystone_project_domain_name => 'domainx',
-          :keystone_user_domain_name    => 'domainx',
-          :keystone_auth_type           => 'password',
-          :keystone_auth_uri            => 'https://foo.bar:5000',
-          :keystone_auth_url            => 'https://foo.bar:35357/deprecated',
-          :keystone_identity_uri        => 'https://foo.bar:35357/deprecated',
-        })
-      end
-      it 'configures auth_uri but deprecates old auth settings' do
-        is_expected.to contain_aodh_config('keystone_authtoken/auth_uri').with_value("https://foo.bar:5000");
-        is_expected.to contain_aodh_config('keystone_authtoken/auth_url').with_value("https://foo.bar:35357/deprecated");
-        is_expected.to contain_aodh_config('keystone_authtoken/username').with_value('user')
-        is_expected.to contain_aodh_config('keystone_authtoken/password').with_value('userpassword')
-        is_expected.to contain_aodh_config('keystone_authtoken/project_name').with_value('tenant')
-        is_expected.to contain_aodh_config('keystone_authtoken/user_domain_name').with_value('domainx')
-        is_expected.to contain_aodh_config('keystone_authtoken/project_domain_name').with_value('domainx')
-        is_expected.to contain_aodh_config('keystone_authtoken/auth_type').with_value('password')
-      end
-    end
   end
 
   on_supported_os({
@@ -189,7 +165,6 @@ describe 'aodh::api' do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts({
           :fqdn           => 'some.host.tld',
-          :processorcount => 2,
           :concat_basedir => '/var/lib/puppet/concat'
         }))
       end
