@@ -4,9 +4,13 @@ describe 'aodh' do
 
   shared_examples 'aodh' do
 
+    it { is_expected.to contain_class('aodh::deps') }
+    it { is_expected.to contain_class('aodh::db') }
+    it { is_expected.to contain_class('aodh::logging') }
+
     context 'with default parameters' do
       let :params do
-        { :purge_config => false  } 
+        { :purge_config => false  }
       end
 
       it 'contains the logging class' do
@@ -22,13 +26,9 @@ describe 'aodh' do
       end
 
       it 'configures rabbit' do
-        is_expected.to contain_aodh_config('DEFAULT/rpc_backend').with_value('rabbit')
         is_expected.to contain_aodh_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_password').with_value('<SERVICE DEFAULT>').with_secret(true)
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_userid').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
@@ -50,15 +50,11 @@ describe 'aodh' do
         {
           :debug                              => true,
           :default_transport_url              => 'rabbit://rabbit_user:password@localhost:5673',
-          :rabbit_host                        => 'rabbit',
-          :rabbit_userid                      => 'rabbit_user',
-          :rabbit_port                        => '5673',
-          :rabbit_password                    => 'password',
           :rabbit_ha_queues                   => 'undef',
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
           :kombu_compression                  => 'gzip',
-          :ensure_package                     => '2012.1.1-15.el6',
+          :package_ensure                     => '2012.1.1-15.el6',
           :gnocchi_url                        => 'http://127.0.0.1:8041',
           :notification_transport_url         => 'rabbit://rabbit_user:password@localhost:5673',
           :notification_driver                => 'ceilometer.compute.aodh_notifier',
@@ -68,13 +64,7 @@ describe 'aodh' do
       end
 
       it 'configures rabbit' do
-        is_expected.to contain_aodh_config('DEFAULT/rpc_backend').with_value('rabbit')
         is_expected.to contain_aodh_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_host').with_value('rabbit')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_password').with_value('password').with_secret(true)
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_port').with_value('5673')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_userid').with_value('rabbit_user')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/heartbeat_rate').with_value('10')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_compression').with_value('gzip')
@@ -98,45 +88,15 @@ describe 'aodh' do
 
     end
 
-    context 'with rabbit_hosts parameter' do
+    context 'with kombu_reconnect_delay set to 5.0 and kombu_failover_strategy' do
       let :params do
-        { :rabbit_hosts => ['rabbit:5673', 'rabbit2:5674'] }
-      end
-
-      it 'configures rabbit' do
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673,rabbit2:5674')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(true)
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
-      end
-    end
-
-    context 'with rabbit_hosts parameter (one server)' do
-      let :params do
-        { :rabbit_hosts => ['rabbit:5673'] }
-      end
-
-      it 'configures rabbit' do
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
-      end
-    end
-
-    context 'with kombu_reconnect_delay set to 5.0' do
-      let :params do
-        { :kombu_reconnect_delay => '5.0' }
+        { :kombu_reconnect_delay   => '5.0',
+          :kombu_failover_strategy => 'test' }
       end
 
       it 'configures rabbit' do
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('5.0')
+        is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('test')
       end
     end
 
@@ -150,10 +110,9 @@ describe 'aodh' do
       end
     end
 
-    context 'with rabbit_ha_queues set to false and with rabbit_hosts' do
+    context 'with rabbit_ha_queues set to false' do
       let :params do
-        { :rabbit_ha_queues => 'false',
-          :rabbit_hosts => ['rabbit:5673'] }
+        { :rabbit_ha_queues => 'false' }
       end
 
       it 'configures rabbit' do
@@ -163,86 +122,70 @@ describe 'aodh' do
 
     context 'with amqp_durable_queues parameter' do
       let :params do
-        { :rabbit_hosts => ['rabbit:5673'],
-          :amqp_durable_queues => 'true' }
+        { :amqp_durable_queues => 'true' }
       end
 
       it 'configures rabbit' do
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(true)
+        is_expected.to contain_oslo__messaging__rabbit('aodh_config').with(
+          :rabbit_use_ssl => '<SERVICE DEFAULT>',
+        )
       end
     end
 
     context 'with rabbit ssl enabled with kombu' do
       let :params do
-        { :rabbit_hosts       => ['rabbit:5673'],
-          :rabbit_use_ssl     => true,
+        { :rabbit_use_ssl     => true,
           :kombu_ssl_ca_certs => '/etc/ca.cert',
           :kombu_ssl_certfile => '/etc/certfile',
           :kombu_ssl_keyfile  => '/etc/key',
           :kombu_ssl_version  => 'TLSv1', }
       end
 
-      it 'configures rabbit' do
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(true)
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('/etc/ca.cert')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('/etc/certfile')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('/etc/key')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('TLSv1')
-      end
+      it { is_expected.to contain_oslo__messaging__rabbit('aodh_config').with(
+        :rabbit_use_ssl     => true,
+        :kombu_ssl_ca_certs => '/etc/ca.cert',
+        :kombu_ssl_certfile => '/etc/certfile',
+        :kombu_ssl_keyfile  => '/etc/key',
+        :kombu_ssl_version  => 'TLSv1',
+      )}
     end
 
     context 'with rabbit ssl enabled without kombu' do
       let :params do
-        { :rabbit_hosts       => ['rabbit:5673'],
-          :rabbit_use_ssl     => true, }
+        { :rabbit_use_ssl => true, }
       end
 
-      it 'configures rabbit' do
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(true)
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
+      it { is_expected.to contain_oslo__messaging__rabbit('aodh_config').with(
+        :rabbit_use_ssl => true,
+      )}
+    end
+
+    context 'with default amqp parameters' do
+      it 'configures amqp' do
+        is_expected.to contain_aodh_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('oslo_messaging_amqp/container_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('oslo_messaging_amqp/idle_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('oslo_messaging_amqp/trace').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('oslo_messaging_amqp/ssl_ca_file').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('oslo_messaging_amqp/ssl_cert_file').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('oslo_messaging_amqp/ssl_key_file').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('oslo_messaging_amqp/ssl_key_password').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('oslo_messaging_amqp/username').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('oslo_messaging_amqp/password').with_value('<SERVICE DEFAULT>')
       end
     end
 
-    context 'with amqp rpc_backend' do
+    context 'with overridden amqp parameters' do
       let :params do
-        { :rpc_backend => 'amqp' }
-      end
-
-      context 'with default parameters' do
-        it 'configures amqp' do
-          is_expected.to contain_aodh_config('DEFAULT/rpc_backend').with_value('amqp')
-          is_expected.to contain_aodh_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_aodh_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_aodh_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_aodh_config('oslo_messaging_amqp/container_name').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_aodh_config('oslo_messaging_amqp/idle_timeout').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_aodh_config('oslo_messaging_amqp/trace').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_aodh_config('oslo_messaging_amqp/ssl_ca_file').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_aodh_config('oslo_messaging_amqp/ssl_cert_file').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_aodh_config('oslo_messaging_amqp/ssl_key_file').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_aodh_config('oslo_messaging_amqp/ssl_key_password').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_aodh_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_aodh_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_aodh_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_aodh_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_aodh_config('oslo_messaging_amqp/username').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_aodh_config('oslo_messaging_amqp/password').with_value('<SERVICE DEFAULT>')
-        end
-      end
-    end
-
-    context 'with overriden amqp parameters' do
-      let :params do
-        { :rpc_backend           => 'amqp',
-          :default_transport_url => 'amqp://amqp_user:password@localhost:5672',
+        {  :default_transport_url => 'amqp://amqp_user:password@localhost:5672',
           :amqp_idle_timeout     => '60',
           :amqp_trace            => true,
           :amqp_ssl_ca_file      => '/etc/ca.cert',
@@ -254,7 +197,6 @@ describe 'aodh' do
       end
 
       it 'configures amqp' do
-        is_expected.to contain_aodh_config('DEFAULT/rpc_backend').with_value('amqp')
         is_expected.to contain_aodh_config('DEFAULT/transport_url').with_value('amqp://amqp_user:password@localhost:5672')
         is_expected.to contain_aodh_config('oslo_messaging_amqp/idle_timeout').with_value('60')
         is_expected.to contain_aodh_config('oslo_messaging_amqp/trace').with_value('true')
